yakumo.neutron.v2.metering

Package yakumo :: Package neutron :: Package v2 :: Package metering |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.neutron.v2.metering

     1  from . import label
     2  from . import rule
     3
     4
     5 -class Client(object):
     6
     7 -    def __init__(self, client, **kwargs):
     8          self.label = label.Manager(client, **kwargs)
     9          self.rule = rule.Manager(client, **kwargs)
    10